DocumentsLocalModel class

Constructors

DocumentsLocalModel({String? id, String? docName, String? fileName, String? fileUrl, String? formatType, int? galleryType, XFile? file, File? pdfFile})

Properties

docName String?
getter/setter pair
file ↔ XFile?
GalleryType
getter/setter pair
fileName String?
getter/setter pair
fileUrl String?
getter/setter pair
formatType String?
getter/setter pair
galleryType int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
pdfFile File?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited