TableFixedFieldData class

Constructors

TableFixedFieldData({String? siNo, String? itemCode, String? itemName, String? hsnCode, String? description, String? quantity, String? unit, String? rate, String? price, String? amount, String? discountPer, String? discountAmt, String? taxPer, String? taxAmt, String? total, String? remarks})

Properties

amount String?
getter/setter pair
description String?
getter/setter pair
discountAmt String?
getter/setter pair
discountPer String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hsnCode String?
getter/setter pair
itemCode String?
getter/setter pair
itemName String?
getter/setter pair
price String?
getter/setter pair
quantity String?
getter/setter pair
rate String?
getter/setter pair
remarks String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siNo String?
getter/setter pair
taxAmt String?
getter/setter pair
taxPer String?
getter/setter pair
total String?
getter/setter pair
unit String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited