PrintDesignerPackageController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • PrintDesignerPackageController
Implemented types

Constructors

PrintDesignerPackageController({required List<String> tabs, required String screen, required Map<String, dynamic> templateData})

Properties

bodyHeight → RxDouble
final
draggingItemId → Rx<String?>
final
erpTableFields List<Map<String, String>>
final
expandedSections → RxList<String>
final
fieldCategories Map<String, List<Map<String, String>>>
final
footerHeight → RxDouble
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
headerHeight → RxDouble
final
id String?
getter/setter pair
initialHeight → RxDouble
final
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
invoiceTableYOffset → RxDouble
final
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isImageUploadButtonLoading → RxBool
final
isMultiSelectDragging → RxBool
final
isPrefixNeeded → RxBool
final
isPrefixTextSelected → RxBool
final
items → RxList<PrinterDesignerPackageListModel>
final
itemStartPosition → Rx<Offset?>
final
jsonOne Map<String, dynamic>
JSON STRINGS
getter/setter pair
lastDraggedItemId → Rx<String?>
final
listeners int
no setterinherited
maxLengthFromBranchName → RxString
final
maxLengthToBranchName → RxString
final
noOfTableRows → RxString
final
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
originalItemPosition → Rx<Offset?>
final
originalItemSize → Rx<Size?>
final
pickedImage → Rx<XFile?>
final
pickedImageWeb → Rx<String?>
final
resizeStartPosition → Rx<Offset?>
final
resizingItemId → Rx<String?>
final
resizingSection → RxString
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen String
final
secondTableVisibleHeaders → RxList<Map<String, dynamic>>
final
sectionYPositions → RxMap<String, double>
final
selectedImages ↔ RxList<XFile>
getter/setter pair
selectedItem PrinterDesignerPackageListModel?
no setter
selectedItemId → Rx<String?>
final
selectedItemIds → RxSet<String>
final
selectedTemplate → RxBool
final
selectionEndPoint → Rx<Offset?>
final
selectionRect → Rx<Rect?>
final
selectionStartPoint → Rx<Offset?>
final
signUrlUploaded → RxString
final
subBodyHeight → RxDouble
final
subHeaderHeight → RxDouble
final
tableEndY → RxDouble
final
tableHeight → RxDouble
final
tableStartY → RxDouble
final
tableVisibleHeaders → RxList<Map<String, dynamic>>
final
tabs List<String>
final
tabsJson Map<String, Map<String, dynamic>>
getter/setter pair
templateData Map<String, dynamic>
final
totalHeight → RxDouble
final

Methods

$configureLifeCycle() → void
inherited
addItem({required String type, required String label, required String section, required String value, required String prefix, required String urlString, Map<String, dynamic>? properties}) → void
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
adjustSecondTableHeaderWidths() → void
adjustTableHeaderWidths() → void
clearSelection() → void
collapseAllSections() → void
convertJsonStringPositions(String positionJson) List<PrinterDesignerPackageListModel>
do not remove
convertJsonStringTableHeaders() List<Map<String, dynamic>>?
deselectItem() → void
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
endResizing() → void
endSelection() → void
generateCurrentTabData() Map<String, dynamic>
Generate data for the current tab
generateJsonString() String
getCurrentTabData() Map<String, dynamic>
Instance method to get current tab data
getTabData(String tabName) Map<String, dynamic>
Get data for a specific tab
handlePointerDown(PointerDownEvent event) → void
handlePointerMove(PointerMoveEvent event) → void
handlePointerUp(PointerUpEvent event) → void
handleResizeEnd() → void
handleResizeStart(String itemId, Offset startPosition, Size currentSize) → void
handleResizeUpdate(Offset currentPosition) → void
initializeTabsJson() → void
Initialize tabsJson for all tabs
loadTabData(String tabName) → void
Load data for a specific tab
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
removeSelectedItem() → void
resetToDefaultTemplate() → void
saveCurrentTabData() → void
Save current tab data to tabsJson
selectItem({required String itemId}) → void
setTabData(String tabName, Map<String, dynamic> data) → void
Set data for a specific tab
startResizing(String section) → void
startSelection(Offset point) → void
switchToTab(String tabName) → void
Switch to a different tab and load its data
toggleItemSelection(String itemId) → void
toggleSection(String sectionTitle) → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateItemProperties({required String itemId, Map<String, dynamic>? properties, double? positionX, double? positionY, double? height, double? width, String? customText, String? value, String? prefix}) → void
updateSecondTableHeaderWidth(String header, double width) → void
updateSectionHeight(String section, double delta) → void
updateSelection(Offset point) → void
updateSelectionRect() → void
updateTableHeaderWidth(String header, double width) → void
do not remove
uploadImageToS3() Future<String?>
////////////////////////////////////////////////////////////////////////

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

collectAllTabsData(List<String> tabs, Map<String, dynamic> templateData) Map<String, dynamic>
Static method to collect data from all controller instances