PrintDesignerPackageController class
- Inheritance
-
- Object
- GetLifeCycle
- DisposableInterface
- GetxController
- PrintDesignerPackageController
- Implemented types
-
Methods
-
$configureLifeCycle()
→ void
-
inherited
-
addItem({required String type, required String label, required String section, required String value, required String prefix, required String urlString, Map<String, dynamic>? properties})
→ void
-
-
addListener(GetStateUpdate listener)
→ Disposer
-
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(Object? key, GetStateUpdate listener)
→ Disposer
-
inherited
-
-
-
clearSelection()
→ void
-
-
collapseAllSections()
→ void
-
-
convertJsonStringPositions(String positionJson)
→ List<PrinterDesignerPackageListModel>
-
do not remove
-
-
deselectItem()
→ void
-
-
dispose()
→ void
-
inherited
-
disposeId(Object id)
→ void
-
To dispose an
id from future updates(), this ids are registered
by GetBuilder() or similar, so is a way to unlink the state change with
the Widget from the Controller.
inherited
-
endResizing()
→ void
-
-
endSelection()
→ void
-
-
generateCurrentTabData()
→ Map<String, dynamic>
-
Generate data for the current tab
-
generateJsonString()
→ String
-
-
getCurrentTabData()
→ Map<String, dynamic>
-
Instance method to get current tab data
-
getTabData(String tabName)
→ Map<String, dynamic>
-
Get data for a specific tab
-
handlePointerDown(PointerDownEvent event)
→ void
-
-
handlePointerMove(PointerMoveEvent event)
→ void
-
-
handlePointerUp(PointerUpEvent event)
→ void
-
-
handleResizeEnd()
→ void
-
-
handleResizeStart(String itemId, Offset startPosition, Size currentSize)
→ void
-
-
handleResizeUpdate(Offset currentPosition)
→ void
-
-
initializeTabsJson()
→ void
-
Initialize tabsJson for all tabs
-
loadTabData(String tabName)
→ void
-
Load data for a specific tab
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyChildrens()
→ void
-
inherited
-
onClose()
→ void
-
Called before
onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onInit()
→ void
-
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
-
onReady()
→ void
-
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
refresh()
→ void
-
inherited
-
refreshGroup(Object id)
→ void
-
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(Object id, VoidCallback listener)
→ void
-
inherited
-
removeSelectedItem()
→ void
-
-
resetToDefaultTemplate()
→ void
-
-
saveCurrentTabData()
→ void
-
Save current tab data to tabsJson
-
selectItem({required String itemId})
→ void
-
-
setTabData(String tabName, Map<String, dynamic> data)
→ void
-
Set data for a specific tab
-
startResizing(String section)
→ void
-
-
startSelection(Offset point)
→ void
-
-
switchToTab(String tabName)
→ void
-
Switch to a different tab and load its data
-
toggleItemSelection(String itemId)
→ void
-
-
toggleSection(String sectionTitle)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
update([List<Object>? ids, bool condition = true])
→ void
-
Rebuilds
GetBuilder each time you call update();
Can take a List of ids, that will only update the matching
GetBuilder( id: ),
ids can be reused among GetBuilders like group tags.
The update will only notify the Widgets, if condition is true.
inherited
-
updateItemProperties({required String itemId, Map<String, dynamic>? properties, double? positionX, double? positionY, double? height, double? width, String? customText, String? value, String? prefix})
→ void
-
-
-
updateSectionHeight(String section, double delta)
→ void
-
-
updateSelection(Offset point)
→ void
-
-
updateSelectionRect()
→ void
-
-
do not remove
-
uploadImageToS3()
→ Future<String?>
-
////////////////////////////////////////////////////////////////////////